dnl Copyright (c) Istituto Nazionale di Fisica Nucleare (INFN). 2006-2010.
dnl
dnl Licensed under the Apache License, Version 2.0 (the "License");
dnl you may not use this file except in compliance with the License.
dnl You may obtain a copy of the License at
dnl
dnl     http://www.apache.org/licenses/LICENSE-2.0
dnl
dnl Unless required by applicable law or agreed to in writing, software
dnl distributed under the License is distributed on an "AS IS" BASIS,
dnl WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
dnl See the License for the specific language governing permissions and
dnl limitations under the License.

dnl Usage:
dnl AC_XERCES_C(MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for xerces-c, and defines
dnl - XERCES_C_LIBS (linker flags, stripping and path)
dnl - XERCES_C_LOCATION

dnl AC_XERCES_C_DEVEL(MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for xmlrpc-c-devel, and defines
dnl - XERCES_C_DEVEL_CFLAGS (compiler flags)
dnl - XERCES_C_DEVEL_LIBS (linker flags, stripping and path)
dnl - XERCES_C_DEVEL_LOCATION

AC_DEFUN([AC_XERCES_C],
[
    AC_ARG_WITH(xerces_c_prefix,
                [  --with-xerces-c-prefix=PFX   prefix where 'xerces-c' is installed.],
                [],
                with_xerces_c_prefix=${XERCES_C_LOCATION:-/usr}
                )
    AC_MSG_CHECKING([for XERCES_C installation at ])

    if test -n "$with_xerces_c_prefix" ; then
        XERCES_C_LOCATION=$with_xerces_c_prefix
        if test "x$host_cpu" == "xx86_64"; then
            ac_xerces_c_ldlib="-L$with_xerces_c_prefix/lib64 -L$with_xerces_c_prefix/lib"
        else
            ac_xerces_c_ldlib="-L$with_xerces_c_prefix/lib -L$with_xerces_c_prefix/lib64"
        fi
        XERCES_C_LIBS="$ac_xerces_c_ldlib"
        AC_MSG_RESULT([$with_xerces_c_prefix])
    else
        XERCES_C_LOCATION=""
        XERCES_C_LIBS=""
        AC_MSG_ERROR([$with_xerces_c_prefix: no such directory])
    fi

    AC_SUBST(XERCES_C_LOCATION)
    AC_SUBST(XERCES_C_LIBS)
])

AC_DEFUN([AC_XERCES_C_DEVEL],
[
    AC_ARG_WITH(xerces_c_devel_prefix,
                [  --with-xerces-c-devel-prefix=PFX   prefix where 'xerces-c-devel' is installed.],
                [],
                with_xerces_c_devel_prefix=${XERCES_C_DEVEL_LOCATION:-/usr}
                )
    AC_MSG_CHECKING([for XERCES_C_DEVEL installation at ])

    ac_save_CFLAGS=$CFLAGS
    ac_save_LIBS=$LIBS
    if test -n "$with_xercesc_c_devel_prefix" ; then
        XERCES_C_DEVEL_CFLAGS="-I$with_xerces_c_devel_prefix/include"
        if test "x$host_cpu" == "xx86_64"; then
            ac_xerces_c_devel_ldlib="-L$with_xerces_c_devel_prefix/lib64 -L$with_xerces_c_devel_prefix/lib"
        else
            ac_xerces_c_devel_ldlib="-L$with_xerces_c_devel_prefix/lib -L$with_xerces_c_devel_prefix/lib64"
        fi
        XERCES_C_DEVEL_LIBS="$ac_xerces_c_devel_ldlib"
        AC_MSG_RESULT([$with_xerces_c_devel_prefix])
    else
        XERCES_C_DEVEL_CFLAGS=""
        XERCES_C_DEVEL_LIBS=""
        AC_MSG_ERROR([$with_xerces_c_devel_prefix: no such directory])
    fi

    XERCES_C_DEVEL_LIBS="$XERCES_C_LIBS $XERCES_C_DEVEL_LIBS -lxerces-c"
    CFLAGS="$XERCES_C_DEVEL_CFLAGS $CFLAGS"
    LIBS="$XERCES_C_DEVEL_LIBS $LIBS"
    AC_TRY_COMPILE([ #include <xercesc/util/XMLChar.hpp> ],
                   [ int i = 1 ],
                   [ ac_cv_xerces_c_devel_valid=yes ], [ ac_cv_xerces_c_devel_valid=no ])
    CFLAGS=$ac_save_CFLAGS
    LIBS=$ac_save_LIBS
    AC_MSG_RESULT([$ac_cv_xerces_c_devel_valid])

    if test x$ac_cv_xerces_c_devel_valid = xyes ; then
        XERCES_C_DEVEL_LOCATION=$with_xerces_c_devel_prefix
        ifelse([$2], , :, [$2])
    else
        XERCES_C_DEVEL_CFLAGS=""
        XERCES_C_DEVEL_LIBS=""
        ifelse([$3], , :, [$3])
    fi

    AC_SUBST(XERCES_C_DEVEL_LOCATION)
    AC_SUBST(XERCES_C_DEVEL_CFLAGS)
    AC_SUBST(XERCES_C_DEVEL_LIBS)
])
